#if !defined(TORCH_STABLE_ONLY) && !defined(TORCH_TARGET_VERSION)
#pragma once

#ifdef USE_ROCM

#define AOTRITON_VERSION_INT(x, y) (x * 100 + y)
#define AOTRITON_VERSION_CURRENT (AOTRITON_VERSION_MAJOR * 100 + AOTRITON_VERSION_MINOR)

#if AOTRITON_VERSION_CURRENT >= AOTRITON_VERSION_INT(0, 11)
#define AOTRITON_ALWAYS_V3_API 1
#else
#define AOTRITON_ALWAYS_V3_API 0
#endif

#if AOTRITON_VERSION_CURRENT >= AOTRITON_VERSION_INT(0, 10)
#define AOTRITON_V3_API 1
#else
#define AOTRITON_V3_API 0
#endif

#endif

#else
#error "This file should not be included when either TORCH_STABLE_ONLY or TORCH_TARGET_VERSION is defined."
#endif  // !defined(TORCH_STABLE_ONLY) && !defined(TORCH_TARGET_VERSION)
